BoxEntry

Struct BoxEntry 

pub struct BoxEntry(/* private fields */);
A heap-allocated Entry wrapper that uses dynamic dispatch.

While somewhat slower than a statically-dispatched entries, an crate::EntrySink of boxed entries can be heterogeneous rather than requiring all entries to be the same type. This is especially useful for “global” background queues that will consume entries from many different components.

Implementations

Source

impl BoxEntry

pub fn new(entry: impl Entry + Send + 'static) -> BoxEntry

Move the entry to the heap and enable dynamic dispatch.

pub fn inner(&self) -> &(dyn Any + Send + 'static)

Returns a reference to the inner Entry value, which can be used with Any to extract a typed reference.

pub fn inner_mut(&mut self) -> &mut (dyn Any + Send + 'static)

Returns a mutable reference to the inner Entry value, which can be used with Any to extract a typed reference.