pub struct ValidationError(/* private fields */);Expand description
An error type that describes why an crate::Entry isn’t valid. This can be because it violated general contracts
(e.g. writing multiple values with the same name) or because it violated a format-specific contract (e.g. using a
reserved property name).
Unlike the happy-case path, errors are free to allocate. We won’t bend over backwards to ensure fast performance in reporting why entries are invalid!
Implementations
Sourceimpl ValidationError
impl ValidationError
Sourcepub fn builder() -> ValidationErrorBuilder
pub fn builder() -> ValidationErrorBuilder
Create a build that can be used to compose multiple validation failures into a single ValidationError. Note
that if no validation failures are added to the builder, ValidationErrorBuilder::build() will return
Ok, which is useful to track if a side-effect produced any errors.
Sourcepub fn extend(&mut self, other: ValidationError)
pub fn extend(&mut self, other: ValidationError)
Extend this error with all of the validation failures recorded in other.
Sourcepub fn for_field(self, name: &str) -> ValidationError
pub fn for_field(self, name: &str) -> ValidationError
Add the field name context for all of the validation failures reported in self.
Sourcepub fn invalid(reason: impl Into<String>) -> ValidationError
pub fn invalid(reason: impl Into<String>) -> ValidationError
Record a generic validation failure with a reason string.